mathtools.least_power_of_two_greater_equal
==========================================

.. autofunction:: abjad.tools.mathtools.least_power_of_two_greater_equal.least_power_of_two_greater_equal
   :noindex:
